@@ -1,9 +1,6 @@
 package Koha::Contrib::Tamil::Biblio::Dumper;
-{
-  $Koha::Contrib::Tamil::Biblio::Dumper::VERSION = '0.032';
-}
 # ABSTRACT: Class dumping a Koha Catalog
-
+$Koha::Contrib::Tamil::Biblio::Dumper::VERSION = '0.033';
 use Moose;
 
 extends 'AnyEvent::Processor';
@@ -72,8 +69,9 @@ before 'run' => sub {
             if @$branches;
     }
     unless ($query) {
-        $query = "SELECT DISTINCT biblionumber FROM items";
-        $query = "$query WHERE $where" if $where;
+        $query = $where
+                 ? "SELECT DISTINCT biblionumber FROM items WHERE $where"
+                 : "SELECT biblionumber FROM biblioitems";
     }
     #say $query;
     my $sth = $self->koha->dbh->prepare($query);
@@ -171,7 +169,7 @@ Koha::Contrib::Tamil::Biblio::Dumper - Class dumping a Koha Catalog
 
 =head1 VERSION
 
-version 0.032
+version 0.033
 
 =HEAD1 SYNOPSIS
 
@@ -181,7 +179,7 @@ Frédéric Demians <f.demians@tamil.fr>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2013 by Fréderic Démians.
+This software is Copyright (c) 2014 by Fréderic Démians.
 
 This is free software, licensed under:
 
